#####################################################################
# EJ(20170302)
# NEA indicators
#####################################################################

library(reshape2)
library(ggplot2)
library(lme4)
library(influence.ME)
library(lattice)
library(parallel)
source("funs.R")
theme_set(theme_bw())
options(stringsAsFactors=FALSE)
v0 <- 2003:2015
v0[seq(2,12,2)] <- ""
sc <- scale_x_continuous(breaks=2003:2015, labels=as.character(v0))
th <- theme(axis.text.x  = element_text(angle=90, vjust=0.5), panel.grid.minor = element_blank())
it <- 500
nc <- 8
# to control de seed in mclapply
RNGkind("L'Ecuyer-CMRG")
set.seed(1234)

#====================================================================
# Load data and subset
#====================================================================

#--------------------------------------------------------------------
# load
#--------------------------------------------------------------------

# assessments
isa <- read.csv("ICESstks_polished_v2.csv", stringsAsFactors=FALSE)

# Stocks to retain from matching the sampling frame with ICES assessments
load("RData.stksnea")

#--------------------------------------------------------------------
# subset
#--------------------------------------------------------------------
# filtering
saeu <- subset(isa, FishStock %in% stkToRetain)
stkToDrop <- unique(isa[!(isa$FishStock %in% stkToRetain), c("FishStock", "EcoRegion", "Category")])
write.csv(stkToDrop, file="stkToDropBySampFrame-nea.csv")

# fixing BMSYescapment not reported by ICES
saeu$MSYBescapement <- NA

# NOP 34 
saeu[saeu$FishStock == "nop-34-oct", c("StockSize", "MSYBescapement")] <- saeu[saeu$FishStock == "nop-34-oct", c("Low_StockSize", "Blim")]

# ANE BISC - need to add value from ss, using upper trigger as proxy for MSYBescapement
saeu[saeu$FishStock == "ane-bisc", "MSYBescapement"] <- 89000 

# acording to the sumsheets SAN and SPR-NSEA use Bpa for MSYBescapement
saeu[saeu$FishStock %in% c("san-ns1", "san-ns2", "san-ns3", "spr-nsea"),"MSYBescapement"] <- saeu[saeu$FishStock %in% c("san-ns1", "san-ns2", "san-ns3", "spr-nsea"),"Bpa"]

# fixing Recruitments of 0
saeu[saeu$Recruitment==0 & !is.na(saeu$Recruitment),"Recruitment"] <- NA

#====================================================================
# Process data
#====================================================================
#--------------------------------------------------------------------
# Bref = Bpa
#--------------------------------------------------------------------
saeu$Bref <- saeu$Bpa
# B escapement as Bref for relevant stocks
saeu$Bref[!is.na(saeu$MSYBescapement)] <- saeu$MSYBescapement[!is.na(saeu$MSYBescapement)]
saeu$Bref <- as.numeric(saeu$Bref)
# set 0 as NA
saeu$Bref[saeu$Bref==0] <- NA

#--------------------------------------------------------------------
# Fref
#--------------------------------------------------------------------
saeu$Fref <- saeu$FMSY
# no Fref for B escapement 
saeu$Fref[!is.na(saeu$MSYBescapement)] <- NA
saeu$Fref <- as.numeric(saeu$Fref)
saeu$Fref[saeu$Fref==0] <- NA

saeu$Frefpa <- saeu$Fpa
# no Fref for B escapement 
saeu$Frefpa[!is.na(saeu$MSYBescapement)] <- NA
saeu$Frefpa <- as.numeric(saeu$Frefpa)
saeu$Frefpa[saeu$Frefpa==0] <- NA

#--------------------------------------------------------------------
# COMPUTE F/Fref and B/Bref | year + stock
#--------------------------------------------------------------------
saeu <- transform(saeu, indF = FishingPressure/Fref, indBpa=StockSize/Bref, indFpa = FishingPressure/Frefpa)
# in case of escapement strategy MSY evaluated by SSB ~ Blim/Bpa/etc
saeu$indF[!is.na(saeu$MSYBescapement)] <- saeu$Bref[!is.na(saeu$MSYBescapement)]/saeu$StockSize[!is.na(saeu$MSYBescapement)]
saeu <- transform(saeu, sfFind=!is.na(indF))

#--------------------------------------------------------------------
# COMPUTE SBL | year + FishStock
#--------------------------------------------------------------------
saeu$SBL <- !(saeu$indFpa > 1 | saeu$indBpa < 1)
# if one is NA SBL can't be inferred
saeu$SBL[is.na(saeu$indFpa) | is.na(saeu$indBpa)] <- NA
# no SBL for B escapement 
saeu$SBL[!is.na(saeu$MSYBescapement)] <- NA
saeu <- transform(saeu, sfSBL=!is.na(SBL))

#--------------------------------------------------------------------
# COMPUTE CFP objectives | year + FishStock
#--------------------------------------------------------------------
saeu$CFP <- !(saeu$indF > 1 | saeu$indBpa < 1)
# if one is NA CFP can't be inferred
saeu$CFP[is.na(saeu$indF) | is.na(saeu$indBpa)] <- NA
# no CFP for B escapement 
saeu$CFP[!is.na(saeu$MSYBescapement)] <- NA
saeu <- transform(saeu, sfCFP=!is.na(CFP))

#--------------------------------------------------------------------
# final dataset
#--------------------------------------------------------------------
saeu <- subset(saeu, Year>=2003 & Year<AssessmentYear & sfFind)

#====================================================================
# Indicators (design based)
#====================================================================

#--------------------------------------------------------------------
# Number of stocks
#--------------------------------------------------------------------
inStks <- getNoStks(saeu, "FishStock", length)

png("figNEAI0a.png", 600, 400)
ggplot(subset(inStks, EcoRegion=="ALL"), aes(x=Year, y=N)) + 
	geom_line() + 
	ylab("No. of stocks") + 
	xlab("") + 
	ylim(c(0,75)) + 
	sc + 
	th  
dev.off()

# time series
png("figNEAI0b.png", 600, 800)
ggplot(saeu, aes(Year, FishStock)) + 
	#geom_line() + 
	geom_point(size=0.5) + 
	ylab("Stock") +
	xlab("Year") +
	sc + 
	scale_y_discrete(name="", limits = rev(unique(saeu$FishStock))) +
	th
dev.off()

# table
write.csv(dcast(inStks, EcoRegion~Year, value.var='N'), file="tabNEAI0.csv", row.names=FALSE) 

#--------------------------------------------------------------------
# Stocks F > Fmsy
#--------------------------------------------------------------------
fInda <- getNoStks(saeu, "indF", function(x) sum(x>1))
fInda[fInda$EcoRegion=="Bay of Biscay and the Iberian Coast", "EcoRegion"] <- "BoBiscay & Iberia"

# plot
png("figNEAI1.png", 600, 400)
ggplot(subset(fInda, EcoRegion=='ALL'), aes(x=Year, y=N)) + 
	geom_line() +
	expand_limits(y=0) + 
	geom_point(aes(x=2003, y=N[1])) +
	geom_point(aes(x=2015, y=N[length(N)]), size=2) + 
	ylab("No. of stocks") + 
	xlab("") + 
	ylim(c(0,75)) + 
	sc + 
	th 
dev.off()

# plot
png("figNEAI1b.png", 800, 400)
ggplot(subset(fInda, EcoRegion != 'ALL'), aes(x=Year, y=N)) + 
	geom_line() + 
	facet_grid(.~EcoRegion) +
	ylab("No. of stocks") + 
	xlab("") + 
	sc + 
	ylim(0, 20) + 
	th
dev.off()

# table
write.csv(dcast(fInda, EcoRegion~Year, value.var='N'), file="tabNEAI1.csv", row.names=FALSE)

#--------------------------------------------------------------------
# Stocks F <= Fmsy
#--------------------------------------------------------------------
fIndb <- getNoStks(saeu, "indF", function(x) sum(x<=1))
fIndb[fIndb$EcoRegion=="Bay of Biscay and the Iberian Coast", "EcoRegion"] <- "BoBiscay & Iberia"

# plot
png("figNEAI2.png", 600, 400)
ggplot(subset(fIndb, EcoRegion=='ALL'), aes(x=Year, y=N)) + 
	geom_line() + 
	expand_limits(y=0) + 
	geom_point(aes(x=2003, y=N[1])) + 
	geom_point(aes(x=2015, y=N[length(N)]), size=2) +
	ylab("No. of stocks") + 
	xlab("") + 
	ylim(c(0,75)) + 
	sc + 
	th
dev.off()

# plot
png("figNEAI2b.png", 800, 400)
ggplot(subset(fIndb, EcoRegion != 'ALL'), aes(x=Year, y=N)) + 
	geom_line() + 
	facet_grid(.~EcoRegion) +
	ylab("No. of stocks") + 
	xlab("") + 
	sc + 
	ylim(0, 20) + 
	th
dev.off()

# table
write.csv(dcast(fIndb, EcoRegion~Year, value.var='N'), file="tabNEAI2.csv", row.names=FALSE)

#--------------------------------------------------------------------
# Stocks outside SBL
#--------------------------------------------------------------------
fIndc <- getNoStks(saeu, "SBL", function(x) sum(!x, na.rm=TRUE))
fIndc[fIndc$EcoRegion=="Bay of Biscay and the Iberian Coast", "EcoRegion"] <- "BoBiscay & Iberia"

# plot
png("figNEAI3.png", 600, 400)
ggplot(subset(fIndc, EcoRegion=='ALL'), aes(x=Year, y=N)) + 
	geom_line() + 
	expand_limits(y=0) + 
	geom_point(aes(x=2003, y=N[1])) +
	geom_point(aes(x=2015, y=N[length(N)]), size=2) + 
	ylab("No. of stocks") + 
	xlab("") + 
	ylim(c(0,75)) + 
	sc + 
	th
dev.off()

# plot
png("figNEAI3b.png", 800, 400)
ggplot(subset(fIndc, EcoRegion != 'ALL'), aes(x=Year, y=N)) + 
	geom_line() + 
	facet_grid(.~EcoRegion) +
	ylab("No. of stocks") + 
	xlab("") + 
	sc + 
	ylim(0, 10) + 
	th
dev.off()

# table
write.csv(dcast(fIndc, EcoRegion~Year, value.var='N'), file="tabNEAI3.csv", row.names=FALSE)

#--------------------------------------------------------------------
# Stocks inside SBL
#--------------------------------------------------------------------
fIndd <- getNoStks(saeu, "SBL", function(x) sum(x, na.rm=TRUE))
fIndd[fIndd$EcoRegion=="Bay of Biscay and the Iberian Coast", "EcoRegion"] <- "BoBiscay & Iberia"

## plot
png("figNEAI4.png", 600, 400)
ggplot(subset(fIndd, EcoRegion=='ALL'), aes(x=Year, y=N)) + 
	geom_line() + 
	expand_limits(y=0) + 
	geom_point(aes(x=2003, y=N[1])) +
	geom_point(aes(x=2015, y=N[length(N)]), size=2) + 
	ylab("No. of stocks") + 
	xlab("") + 
	ylim(c(0,75)) + 
	sc + 
	th
dev.off()

# plot
png("figNEAI4b.png", 800, 400)
ggplot(subset(fIndd, EcoRegion != 'ALL'), aes(x=Year, y=N)) + 
	geom_line() + 
	facet_grid(.~EcoRegion) +
	ylab("No. of stocks") + 
	xlab("") + 
	sc + 
	ylim(0, 10) + 
	th
dev.off()

# table
write.csv(dcast(fIndd, EcoRegion~Year, value.var='N'), file="tabNEAI4.csv", row.names=FALSE)

#--------------------------------------------------------------------
# Stocks outside CFP objectives
#--------------------------------------------------------------------

fIndf <- getNoStks(saeu, "CFP", function(x) sum(!x, na.rm=TRUE))
fIndf[fIndf$EcoRegion=="Bay of Biscay and the Iberian Coast", "EcoRegion"] <- "BoBiscay & Iberia"

## plot
png("figNEAI7.png", 600, 400)
ggplot(subset(fIndf, EcoRegion=='ALL'), aes(x=Year, y=N)) + 
	geom_line() + 
	expand_limits(y=0) + 
	geom_point(aes(x=2003, y=N[1])) +
	geom_point(aes(x=2015, y=N[length(N)]), size=2) + 
	ylab("No. of stocks") + 
	xlab("") + 
	ylim(c(0,75)) + 
	sc + 
	th
dev.off()

# plot
png("figNEAI7b.png", 800, 400)
ggplot(subset(fIndf, EcoRegion != 'ALL'), aes(x=Year, y=N)) + 
	geom_line() + 
	facet_grid(.~EcoRegion) +
	ylab("No. of stocks") + 
	xlab("") + 
	sc + 
	ylim(0, 15) + 
	th
dev.off()

# table
write.csv(dcast(fIndf, EcoRegion~Year, value.var='N'), file="tabNEAI7.csv", row.names=FALSE)

#--------------------------------------------------------------------
# Stocks outside CFP objectives
#--------------------------------------------------------------------
fIndfb <- getNoStks(saeu, "CFP", function(x) sum(x, na.rm=TRUE))
fIndfb[fIndfb$EcoRegion=="Bay of Biscay and the Iberian Coast", "EcoRegion"] <- "BoBiscay & Iberia"

## plot
png("figNEAI8.png", 600, 400)
ggplot(subset(fIndfb, EcoRegion=='ALL'), aes(x=Year, y=N)) + 
	geom_line() + 
	expand_limits(y=0) + 
	geom_point(aes(x=2003, y=N[1])) +
	geom_point(aes(x=2015, y=N[length(N)]), size=2) + 
	ylab("No. of stocks") + 
	xlab("") + 
	ylim(c(0,75)) + 
	sc + 
	th
dev.off()

# plot
png("figNEAI8b.png", 800, 400)
ggplot(subset(fIndfb, EcoRegion != 'ALL'), aes(x=Year, y=N)) + 
	geom_line() + 
	facet_grid(.~EcoRegion) +
	ylab("No. of stocks") + 
	xlab("") + 
	sc + 
	ylim(0, 15) + 
	th
dev.off()

# table
write.csv(dcast(fIndfb, EcoRegion~Year, value.var='N'), file="tabNEAI8.csv", row.names=FALSE)

#--------------------------------------------------------------------
# F/Fmsy
#--------------------------------------------------------------------
idx <- saeu$FishingPressureDescription %in% c("Fishing Pressure: F/Fmsy", "Fishing Pressure: F")
idx <- idx & is.na(saeu$MSYBescapement)
fInde <- getNoStks(saeu[idx,], "indF", function(x) mean(x, na.rm=TRUE), "F")
fInde[fInde$EcoRegion=="Bay of Biscay and the Iberian Coast", "EcoRegion"] <- "BoBiscay & Iberia"

# plot
png("figNEAI5.png", 600, 400)
ggplot(subset(fInde, EcoRegion=='ALL'), aes(x=Year, y=F)) + 
	geom_line() + 
	expand_limits(y=0) + 
	geom_point(aes(x=2003, y=F[1])) +
	geom_point(aes(x=2015, y=F[length(F)]), size=2) + 
	geom_hline(yintercept=1, linetype=2) +
	ylab(expression(F/F[MSY])) + 
	ylim(0, 2.5) + 
	xlab("") + 
	sc + 
	th
dev.off()

# plot
png("figNEAI5b.png", 800, 400)
ggplot(subset(fInde, EcoRegion != 'ALL'), aes(x=Year, y=F)) + 
	geom_line() + 
	geom_hline(yintercept=1, linetype=2) +
	facet_grid(.~EcoRegion) +
	ylab(expression(F/F[MSY])) + 
	xlab("") + 
	ylim(0, 2.5) + 
	sc + 
	th
dev.off()

# table
write.csv(dcast(fInde, EcoRegion~Year, value.var='F'), file="tabNEAI5.csv", row.names=FALSE)

#====================================================================
# Indicators (model based)
#====================================================================

#--------------------------------------------------------------------
# F/Fmsy model
#--------------------------------------------------------------------
idx <- saeu$FishingPressureDescription %in% c("Fishing Pressure: F/Fmsy", "Fishing Pressure: F")
saeu$sfI5 <- idx & is.na(saeu$MSYBescapement)
df0 <- saeu[saeu$sfI5,]
df0[df0$EcoRegion=="Bay of Biscay and the Iberian Coast", "EcoRegion"] <- "BoBiscay & Iberia"
df0$Year <- factor(df0$Year)
yrs <- levels(df0$Year)
nd <- data.frame(Year=factor(yrs))

# fit
ifit <- glmer(indF ~ Year + (1|FishStock), data = df0, family = Gamma("log"), control=glmerControl(optimizer="nlminbwrap"))
runDiagsME(ifit, "FishStock", df0, "diagNEAI5.pdf", nc, nd)

# bootstrap
stk <- unique(df0$FishStock)
ifit.bs <- split(1:it, 1:it) 

ifit.bs <- mclapply(ifit.bs, function(x){
	stk <- sample(stk, replace=TRUE)
	df1 <- df0[0,] 
	for(i in stk) df1 <- rbind(df1, subset(df0, FishStock==i))
	fit <- glmer(indF ~ Year + (1|FishStock), data = df1, family = Gamma("log"), control=glmerControl(optimizer="nlminbwrap"))
	v0 <- predict(fit, re.form=~0, type="response", newdata=nd)
	if(length(fit@optinfo$conv$lme4)>0) v0[] <- NA
	v0
}, mc.cores=nc)

ifitm <- do.call("rbind", ifit.bs)
ifitq <- apply(ifitm, 2, quantile, c(0.025, 0.25, 0.50, 0.75, 0.975), na.rm=TRUE)
ifitq <- cbind(Year=as.numeric(yrs), as.data.frame(t(ifitq)))

# plot
png("figNEAI5mod.png", 600, 400)
ggplot(ifitq, aes(x=Year)) +
  geom_ribbon(aes(ymin = `2.5%`, ymax = `97.5%`), fill="gray", alpha=0.60) +
  geom_ribbon(aes(ymin = `25%`, ymax = `75%`), fill="gray", alpha=0.95) +
  geom_line(aes(y=`50%`)) + expand_limits(y=0) +
  geom_point(aes(x=Year[1], y=`50%`[1])) +
  geom_point(aes(x=Year[length(Year)], y=`50%`[length(`50%`)]), size=2) +
  geom_hline(yintercept = 1, linetype=2) +
  ylab(expression(F/F[MSY])) + 
  ylim(0, 2.5) + 
  xlab("") +
  theme(legend.position = "none") + 
  sc + 
  th
dev.off()

# table
df0 <- t(ifitq)[-1,]
colnames(df0) <- ifitq[,1]
write.csv(df0, file="tabNEAI5mod.csv")

#--------------------------------------------------------------------
# SSB model
#--------------------------------------------------------------------
saeu$sfI6 <- saeu$StockSizeDescription %in% c("Stock Size: SSB", "Stock Size: TSB")
df0 <- saeu[saeu$sfI6,]
df0[df0$EcoRegion=="Bay of Biscay and the Iberian Coast", "EcoRegion"] <- "BoBiscay & Iberia"
df0$Year <- factor(df0$Year)
yrs <- levels(df0$Year)
nd <- data.frame(Year=factor(yrs))

# fit
ifitb <- glmer(StockSize ~ Year + (1|FishStock), data =  df0, family = Gamma("log"), control=glmerControl(optimizer="nlminbwrap")) 
runDiagsME(ifitb, "FishStock", df0, "diagNEAI6.pdf", nc, nd)

# bootstrap
stk <- unique(df0$FishStock)
ifitb.bs <- split(1:it, 1:it) 
ifitb.bs <- mclapply(ifitb.bs, function(x){
	stk <- sample(stk, replace=TRUE)
	df1 <- df0[0,] 
	for(i in stk) df1 <- rbind(df1, subset(df0, FishStock==i))
	fit <- glmer(StockSize ~ Year + (1|FishStock), data = df1, family = Gamma("log"), control=glmerControl(optimizer="nlminbwrap")) 
	v0 <- predict(fit, re.form=~0, type="response", newdata=nd)
	if(length(fit@optinfo$conv$lme4)>0) v0[] <- NA
	v0
}, mc.cores=nc)

ifitm <- do.call("rbind", ifitb.bs)
ifitm <- exp(log(ifitm)-mean(log(ifitm[,1]), na.rm=TRUE))
ifitq <- apply(ifitm, 2, quantile, c(0.025, 0.25, 0.50, 0.75, 0.975), na.rm=TRUE)
ifitq <- cbind(Year=as.numeric(yrs), as.data.frame(t(ifitq)))

# plot
png("figNEAI6.png", 600, 400)
ggplot(ifitq, aes(x=Year)) +
  geom_ribbon(aes(ymin = `2.5%`, ymax = `97.5%`), fill="gray", alpha=0.60) +
  geom_ribbon(aes(ymin = `25%`, ymax = `75%`), fill="gray", alpha=0.95) +
  geom_line(aes(y=`50%`)) + 
  expand_limits(y=0) +
  geom_point(aes(x=Year[1], y=`50%`[1])) +
  geom_point(aes(x=Year[length(Year)], y=`50%`[length(`50%`)]), size=2) +
  geom_hline(yintercept = 1, linetype=2) +
  ylab(expression(B/B[2013])) + 
  xlab("") +
  theme(legend.position = "none") + 
  sc + 
  th
dev.off()

# table
df0 <- t(ifitq)[-1,]
colnames(df0) <- ifitq[,1]
write.csv(df0, file="tabNEAI6.csv")

#--------------------------------------------------------------------
# F/Fmsy stocks outside EU
#--------------------------------------------------------------------
df0 <- subset(isa, EcoRegion %in% c("Iceland Sea and Greenland Sea",
    "Barents Sea and Norwegian Sea","Faroes") | FishStock=="her-noss")
df0$Fref <- df0$FMSY
df0 <- transform(df0, indF = FishingPressure/Fref, sfFind=!is.na(FishingPressure/Fref))
df0 <- subset(df0, Year>=2003 & Year<AssessmentYear & sfFind)
idx <- df0$FishingPressureDescription %in% c("Fishing Pressure: F/Fmsy", "Fishing Pressure: F" )
df0 <- df0[idx,]
df0$Year <- factor(df0$Year)
yrs <- levels(df0$Year)
nd <- data.frame(Year=factor(yrs))
# fit
ifitout <- glmer(indF ~ Year + (1|FishStock), data = df0, family = Gamma("log"), control=glmerControl(optimizer="nlminbwrap")) 
runDiagsME(ifit, "FishStock", df0, "diagNEAI8.pdf", nc, nd)

# bootstrap
stk <- unique(df0$FishStock)
ifitout.bs <- split(1:it, 1:it) 
ifitout.bs <- mclapply(ifitout.bs, function(x){
	stk <- sample(stk, replace=TRUE)
	df1 <- df0[0,] 
	for(i in stk) df1 <- rbind(df1, subset(df0, FishStock==i))
	fit <- glmer(indF ~ Year + (1|FishStock), data = df1, family = Gamma("log"), control=glmerControl(optimizer="nlminbwrap")) 
	v0 <- predict(fit, re.form=~0, type="response", newdata=nd)
	if(length(fit@optinfo$conv$lme4)>0) v0[] <- NA
	v0
}, mc.cores=nc)

ifitm <- do.call("rbind", ifitout.bs)
ifitq <- apply(ifitm, 2, quantile, c(0.025, 0.25, 0.50, 0.75, 0.975), na.rm=TRUE)
ifitq <- cbind(Year=as.numeric(yrs), as.data.frame(t(ifitq)))

# plot
png("figNEAI9.png", 600, 400)
ggplot(ifitq, aes(x=Year)) +
  geom_ribbon(aes(ymin = `2.5%`, ymax = `97.5%`), fill="gray", alpha=0.60) +
  geom_ribbon(aes(ymin = `25%`, ymax = `75%`), fill="gray", alpha=0.95) +
  geom_line(aes(y=`50%`)) + expand_limits(y=0) +
  geom_point(aes(x=Year[1], y=`50%`[1])) +
  geom_point(aes(x=Year[length(Year)], y=`50%`[length(`50%`)]), size=2) +
  ylab(expression(F/F[MSY])) + 
  geom_hline(yintercept = 1, linetype=2) +
  ylim(0, 2.5) + 
  xlab("") +
  theme(legend.position = "none") + 
  sc + 
  th
dev.off()

# table
df0 <- t(ifitq)[-1,]
colnames(df0) <- ifitq[,1]
write.csv(df0, file="tabNEAI9.csv")

#====================================================================
# Stocks used in each indicator
#====================================================================

df0 <- melt(saeu, c('Year', 'FishStock'), c('sfFind', 'sfSBL', 'sfCFP', 'sfI5', 'sfI6'))
df0 <- subset(df0, Year=='2014' & value==TRUE)

levels(df0$variable) <- c('above/below Fmsy', 'in/out SBL', 'in/out CFP', 'F/Fmsy trends', 'Biomass trends')

png("figNEAI0c.png", 600, 800)
ggplot(df0, aes(variable, FishStock)) + 
	#geom_line() + 
	geom_point(size=0.5) + 
	ylab("Stock") +
	xlab("Indicator") +
	scale_y_discrete(name="", limits = rev(unique(df0$FishStock))) +
	th
dev.off()

#====================================================================
# Coverage
#====================================================================
 
# All stocks of relevance
stocks <- subset(saeu, Year==2015)$FishStock
# All stocks with B indicator
bind_stocks <- subset(saeu, Year==2015 & !is.na(indBpa))$FishStock 
# All stocks with F indicator - Same as stocks
find_stocks <- subset(saeu, Year==2015 & !is.na(indF))$FishStock 

# Current list
all_stocks <- unique(sf_ass$FishStock)
# ignore NA
all_stocks <- all_stocks[!is.na(all_stocks)]

# Which stocks to drop from all stocks
drop_stock <- all_stocks[!(all_stocks %in% stocks)]

# Which stocks to drop as no f indicator
drop_stock_f <- all_stocks[!(all_stocks %in% find_stocks)]

# Which stocks to drop as no b indicator
drop_stock_b <- all_stocks[!(all_stocks %in% bind_stocks)]
    
# Set dropped stocks to NA in FishStock column
sf_ass$FindFishStock <- sf_ass$FishStock
sf_ass[sf_ass$FindFishStock %in% drop_stock_f,"FindFishStock"] <- as.character(NA)
sf_ass$BindFishStock <- sf_ass$FishStock
sf_ass[sf_ass$BindFishStock %in% drop_stock_b ,"BindFishStock"] <- as.character(NA)

# Proportion of TACs that have at least one rectangle assessed by FindFishStock and BindFishStock
outf <- aggregate(sf_ass$FindFishStock, by=list(sf_ass$TAC_id), function(x) {
          no_rect_ass_find <- sum(!is.na(x))
          assessed_find <- no_rect_ass_find > 1
          return(assessed_find)
})

outb <- aggregate(sf_ass$BindFishStock, by=list(sf_ass$TAC_id), function(x) {
          no_rect_ass_bind <- sum(!is.na(x))
          assessed_bind <- no_rect_ass_bind > 1
          return(assessed_bind)
})

coverage <- data.frame(No_stocks = c(length(find_stocks), length(bind_stocks)),
           No_TACs = length(unique(sf_ass$TAC_id)),
           Frac_TACs_assessed = c(mean(outf$x),mean(outb$x))
)
rownames(coverage) <- c("F_indicator", "B_indicator")
write.csv(coverage, "coverage.csv")

#====================================================================
# Exporting and saving
#====================================================================

write.csv(saeu[,-which(names(saeu) %in% c("X","X.1","X.2"))], file="saeu.csv")
save.image("RData.nea")

